import 'dart:io';
import 'package:at_utils/at_logger.dart';
import 'package:internet_connection_checker/internet_connection_checker.dart';

class NetworkUtil {
  static final _logger = AtSignLogger('NetworkUtil');

  static Future<bool> isNetworkAvailable() async {
    var result = await InternetConnectionChecker().hasConnection;
    if (!result) {
      _logger.finer('Unable to connect to internet');
    }
    return result;
  }

  static Future<bool> isReachable(String host,int port) async {
    try {
      var internetAddress = await InternetAddress.lookup(host);
      var addressCheckOptions =
      AddressCheckOptions(internetAddress[0], port: port);
      return (await InternetConnectionChecker()
          .isHostReachable(addressCheckOptions))
          .isSuccess;
    } on Exception catch(e) {
      _logger.severe('Cannot reach host:$host port:$port due to exception $e');
      return false;
    }
  }
}
