import 'package:at_client/at_client.dart';
import 'package:at_utils/at_logger.dart';

import '../test_util.dart';

void main() async {
  try {
    AtSignLogger.root_level = 'finer';
    final aliceAtSign = '@alice🛠';
    final bobAtSign = '@bob🛠';
    final atClientManager = await AtClientManager.getInstance()
        .setCurrentAtSign(aliceAtSign, 'wavi', TestUtil.getAlicePreference());

    // alice - listen for notification
    atClientManager.notificationService.subscribe().listen((notification) {
      _notificationCallback(notification);
    });
    Future.delayed(Duration(seconds: 30), () => switchToBob(atClientManager));
    Future.delayed(Duration(seconds: 60), () => switchToAlice(atClientManager));
  } on Exception catch (e, trace) {
    print(e.toString());
    print(trace);
  }
}

Future<void> switchToBob(atClientManager) async {
  print('switching to bob');
  await atClientManager.setCurrentAtSign(
      '@bob🛠', 'wavi', TestUtil.getBobPreference());
  atClientManager.notificationService.subscribe().listen((notification) {
    _notificationCallback(notification);
  });
}

Future<void> switchToAlice(atClientManager) async {
  print('switching to alice');
  await atClientManager.setCurrentAtSign(
      '@alice🛠', 'wavi', TestUtil.getAlicePreference());
  atClientManager.notificationService.subscribe().listen((notification) {
    _notificationCallback(notification);
  });
}

void _notificationCallback(AtNotification notification) {
  print('alice notification received: ${notification.toString()}');
}
